==> arquillian-parent-1.1.13.Final-source-release.zip: arquillian-parent-1.1.13.Final/testng/core/src/main/java/org/jboss/arquillian/testng/State.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.testng;


/**
 * State
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class State
{
   private static ThreadLocal<Throwable> caughtExceptionAfter = new ThreadLocal<Throwable>();

   public static Throwable caughtExceptionAfter()
   {
       return caughtExceptionAfter.get();
   }

   public static void caughtExceptionAfter(Throwable afterException)
   {
      if(afterException == null)
      {
          caughtExceptionAfter.remove();
      }
      else
      {
          caughtExceptionAfter.set(afterException);
      }
   }

   static void clean()
   {
      caughtExceptionAfter.remove();
   }

}

==> arquillian-parent-1.9.3.Final-source-release.zip: arquillian-parent-1.9.3.Final/testng/core/src/main/java/org/jboss/arquillian/testng/State.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.testng;

/**
 * State
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class State {
    private static ThreadLocal<Throwable> caughtExceptionAfter = new ThreadLocal<Throwable>();

    public static Throwable caughtExceptionAfter() {
        return caughtExceptionAfter.get();
    }

    public static void caughtExceptionAfter(Throwable afterException) {
        if (afterException == null) {
            caughtExceptionAfter.remove();
        } else {
            caughtExceptionAfter.set(afterException);
        }
    }

    static void clean() {
        caughtExceptionAfter.remove();
    }
}
